<?php
/*************************************************************************************
 * mn103.php
 * --------
 * Author: Nick Driftwood (driftwood.brighton@gmail.com)
 * Copyright: (c) 2012 Vitaily Kiselev, Nigel McNie (http://qbnz.com/highlighter)
 * Release Version: 1.0.0.0
 * Date Started: 2012/01/26
 *
 * Panasonic mn103 Assembler language file for GeSHi.
 *
 * Syntax definition as commonly used by the Panasonic documentation for the
 * mn103 Microcontroller (MN1030 series).
 *
 * CHANGES
 * -------
 * 2012/01/26 (1.0.0.00)
 *   -  First Release
 *
 * 2012/01/31 (1.0.0.01)
 *   -  Added VK's data storage directives
 *
 * TODO (updated 2012/xx/xx)
 * -------------------------
 * colour tagging
 *
 *************************************************************************************
 *
 *    This file is part of GeSHi.
 *
 *   GeSHi is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   GeSHi is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with GeSHi; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 ************************************************************************************/

$language_data = array (
    'LANG_NAME' => 'mn103',
    'COMMENT_SINGLE' => array(1 => ';'),
    'COMMENT_MULTI' => array(),
    'CASE_KEYWORDS' => GESHI_CAPS_NO_CHANGE,
    'QUOTEMARKS' => array("'", '"'),
    'ESCAPE_CHAR' => '',
    'KEYWORDS' => array(
        /*CPU instructions*/
        1 => array(
            'bset','btst','call','calls','clr','cmp','div','divu',
            'ext','extb','extbu','exth','exthu','inc','inc4','jmp',
            'jsr','lsr','mov','movb','movbu','movh','movhu',
            'movm','mul','mulu','nop','not','or','ret','retf','rets',
            'rol', 'ror', 'rti', 'rts', 'setlb', 'sub', 'subc', 'trap','xor',
            'beq','bne','bgt','bge','ble','blt','bhi','bcc','bls','bcs','bvc','bvs','bnc','bns','bra',
            'leq','lne','lgt','lge','lle','llt','lhi','lcc','lls','lcs','lra'
            ),
        /*udf*/
        2 => array(
            'udf00','udf01','udf02','udf03','udf04','udf05','udf06','udf07',
            'udf08','udf09','udf10','udf11','udf12','udf13','udf14','udf15',
            'udf20','udf21','udf22','udf23','udf24','udf25','udf26','udf27',
            'udf28','udf29','udf30','udf31','udf32','udf33','udf34','udf35'
            ),
        /*udfu*/
        3 => array(
            'udfu00','udfu01','udfu02','udfu03','udfu04','udfu05','udfu06','udfu07',
            'udfu08','udfu09','udfu10','udfu11','udfu12','udfu13','udfu14','udfu15',
            'udfu20','udfu21','udfu22','udfu23','udfu24','udfu25','udfu26','udfu27',
            'udfu28','udfu29','udfu30','udfu31','udfu32','udfu33','udfu34','udfu35'
            ),
        /*registers*/
        4 => array(
            'a0','a1','a2','a3',
            'd0','d1','d2','d3',
            'lir','lar','mdr','pc',
            'psw','sp','dh'
            ),
        /*flags*/
        5 => array(
            'cf','zf','nf','vf'
            ),
        /*Standard Directives*/
        6 => array(
            'dec','ex','label','wb','asr','equ','macro','add','endm',
            'add_adr','end','p1','mac1','mac2','local','exitm','dsize',
            'purge','rept','repeat','irp','irpc','data','load','main','move','align',
            'org','section','opt','global','dc','ds','tit','listoff','liston',
            '_TEXT','_func','_0func','xlistoff','xliston','page','lines','columns',
            'notation','const','format','radix','funcinfo','mesg'
            ),
        /*Assembler Control directives*/
        7 => array(
            '#include','#define','#undef','#if','#else','#endif','#ifdef','#ifndef','#ifn','#ifeq',
            '#ifneq','#iflt','#ifle','#ifgt','#ifge','#ifb','#ifnb',
            'include','define','undef','if','else','endif','ifdef','ifndef','ifn','ifeq',
            'ifneq','iflt','ifle','ifgt','ifge','ifb','ifnb'
            ),
        /*Operands*/
        8 => array(
            'abs16','abs32','d','d8','d16','d32',
            'imm','imm8','imm16','imm24','imm32','imm40','imm48',
            'mem','reg0','reg1','reg2','reg3','reg4','reg5','reg6','reg7','reg8','reg9','reg10','reg11','regs'
            ),
        /*Instruction Formats*/
        9 => array(
            'd4','d5','s0','s1','s2','s4','s6'
            ),
        /*data storage directives*/
        10 => array(
            '.address','.byte','.ascii','.asciiz','.comm','.double','.d_floating','.extended',
            '.float','.f_floating','.gprel32','.g_floating','.lcomm','.lit4','.lit8','.long',
            '.octa','.packed','.quad','.s_floating','.t_floating','.word','.x_floating',
            'db','dd','dw','struct','ends','struc','comment'
            ),
        ),
    'SYMBOLS' => array(
        '[', ']', '(', ')'
        ),
    'CASE_SENSITIVE' => array(
        GESHI_COMMENTS => true,
        1 => false,
        2 => false,
        3 => false,
        4 => false,
        5 => false,
        6 => false,
        7 => false,
        8 => false,
        9 => false,
        10 => false
        ),
    'STYLES' => array(
        'KEYWORDS' => array(
            1 => 'color: #00007f;',
            2 => 'color: #0000ff;',
            3 => 'color: #46aa03; font-weight:bold;',
            4 => 'color: #0000ff;',
            5 => 'color: #0000ff;',
            6 => 'color: #0000ff;',
            7 => 'color: #0000ff;',
            8 => 'color: #0000ff;',
            9 => 'color: #0000ff;',
            10 => 'color: #0000ff;'
            ),
        'COMMENTS' => array(
            1 => 'color: #adadad; font-style: italic;',
            ),
        'ESCAPE_CHAR' => array(
            0 => 'color: #000099; font-weight: bold;'
            ),
        'BRACKETS' => array(
            0 => 'color: #66cc66;'
            ),
        'STRINGS' => array(
            0 => 'color: #7f007f;'
            ),
        'NUMBERS' => array(
            0 => 'color: #ff0000;'
            ),
        'METHODS' => array(
            ),
        'SYMBOLS' => array(
            0 => 'color: #66cc66;'
            ),
        'REGEXPS' => array(
            0 => 'color: #ff0000;',
            1 => 'color: #ff0000;',
            ),
        'SCRIPT' => array(
            )
    ),
    'URLS' => array(
        1 => '',
        2 => '',
        3 => '',
        4 => '',
        5 => '',
        6 => '',
        7 => '',
        8 => '',
        9 => '',
        10 => ''
        ),
    'OOLANG' => false,
    'OBJECT_SPLITTERS' => array(
        ),
    'REGEXPS' => array(
        0 => '0[0-9a-fA-F]{1,32}[hH]',
        1 => '[01]{1,64}[bB]'
        ),
    'STRICT_MODE_APPLIES' => GESHI_NEVER,
    'SCRIPT_DELIMITERS' => array(
        ),
    'HIGHLIGHT_STRICT_BLOCK' => array(
        ),
    'TAB_WIDTH' => 8,
    'PARSER_CONTROL' => array(
        'KEYWORDS' => array(
            'DISALLOWED_BEFORE' => "(?<![a-zA-Z0-9\$_\|\#>|^])",
            'DISALLOWED_AFTER' => "(?![a-zA-Z0-9_<\|%])"
        )
    )
);

?>